@@ -29,7 +29,7 @@
 #include "CNV.h"
 #include "Result.h"
 #include "LeftAlign.h"
-#include "Variant.h"
+#include <Variant.h> // note this can end in vcflib/Variant.h
 #include "version_git.h"
 
 // the size of the window of the reference which is always cached in memory
