@@ -1,4 +1,5 @@
-#pragma once
+#ifndef FREEBAYES_LARGEFILESUPPORT_H
+#define FREEBAYES_LARGEFILESUPPORT_H
 
 #ifdef WIN32
 #define ftell64(a)     _ftelli64(a)
@@ -17,3 +18,5 @@ typedef off_t off_type;
 #define fseek64(a,b,c) fseeko(a,b,c)
 typedef __off64_t off_type;
 #endif
+
+#endif
