@@ -1,3 +1,6 @@
+#ifndef FREEBAYES_TRYCATCH_H
+#define FREEBAYES_TRYCATCH_H
+
 #include <stdexcept> // out_of_range exception
 #include <stdlib.h> // abort
 
@@ -7,10 +10,12 @@
 #endif
 #ifndef CATCH
 #define CATCH \
-    catch (std::out_of_range outOfRange) { \
+    catch (const std::out_of_range& outOfRange) { \
         cerr << "exception: " << outOfRange.what() \
         << " at line " << __LINE__ \
         << " in file " << __FILE__ << endl; \
         abort(); \
     }
 #endif
+
+#endif
